@@ -249,6 +249,7 @@ and C-z for UNDO
   (defun insert-prin1 (args)
     (insert (prin1-to-string args)))
 
+  ;; (setq x 32.456)
   (defun d-show (x)
     (kill-sexp 2)
     (insert (format " %5.2f " (/ (round (* x 100)) 100.0))))
@@ -364,7 +365,7 @@ and C-z for UNDO
 
   (global-set-key [(control next)]        'scroll-up)
   (global-set-key [(meta    next)]        'end-of-defun)
-  (global-set-key [(shift   next)]        'forward-page)
+  (global-set-key [(shift   next)]        'd-forward-page)
 
   (defun d-forward-page ()
     (interactive)
@@ -378,7 +379,7 @@ and C-z for UNDO
 
   (global-set-key [(control prior)]       'scroll-down)
   (global-set-key [(meta    prior)]       'beginning-of-defun)
-  (global-set-key [(shift   prior)]       'backward-page)
+  (global-set-key [(shift   prior)]       'd-backward-page)
 
   (defun d-backward-page ()
     (interactive)
