@@ -610,7 +610,7 @@
             (font-lock-fontify-buffer)
             (while (warn--re-search-forward--no-strings-no-comments
                     "\\<\\([a-z.]+\\.\\)?\\([A-Z][a-zA-Z0-9_]*\\)\\(\\.[a-z][a-zA-Z0-9_]*\\)?\\((\\)?" nil t)
-              (checkpoint "g")
+              ;;(checkpoint "g")
               (if (and (match-beginning 1) (match-end 1))
                   (setq package (match-string 1))
                 (setq package ""))
@@ -1258,6 +1258,37 @@ I am a comment on how to use this function"
                          ) ;; END COND!
                         ;;(if strobe (debug "Queen: One Year of Love"))
                         )
+                       ((string-match "(" (prin1-to-string (nth 3 form)))
+                        ;;(debug "Public Enemy: Letter to the New York Post")
+                        (setq start (concat start (prin1-to-string (nth 3 form))))
+                        (cond
+                         ((eq (nth 4 form) 'to)
+                          (setq to 'to))
+                         ((eq (nth 4 form) 'downto)
+                          (setq to 'downto))
+                         (t
+                          (debug "Elvis: King Creole")))
+                        (setq stop (prin1-to-string (nth 5 form)))
+                        (cond
+                         ((and (eq (nth 6 form) nil) (> (length form) 6))
+                          (setq stop (concat stop "()"))
+                          ;;(debug "The Pretenders: Kid")
+                          (if (eq (nth 7 form) 'step)
+                              (setq step-size (nth 8 form))))
+                         ;; ------------------------------------------
+                         ((string-match "(" (prin1-to-string (nth 6 form)))
+                          (setq stop (concat stop (prin1-to-string (nth 6 form))))
+                          (if (eq (nth 7 form) 'step)
+                              (setq step-size (nth 8 form))))
+                         ;; ------------------------------------------
+                         ((eq (nth 6 form) 'step)
+                          (debug "Pretenders: Private Life")
+                          (setq step-size (nth 7 form)))
+                         (t
+                          ;;(debug "Queen: It's a Kind of Magic")
+                          )
+                         )
+                        )
                        ((eq (nth 3 form) 'to)
                         (setq to 'to)
                         (setq stop (nth 4 form))
@@ -1278,7 +1309,7 @@ I am a comment on how to use this function"
                         (debug "Dire Straits: The Bug")))
                       )
                   (assert (or (eq (nth 3 form) '=)))
-                  ;;(debug "Joaquin Rodrigo")
+                  ;;(debug "Joaquin Rodrigo)
                   (setq start (nth 4 form))
                   (cond
                    ((eq (nth 5 form) 'to)
